<?php
/**
 * Akks Theme Customizer
 *
 * @package akks
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function akks_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'        => '.site-title a',
			'render_callback' => 'akks_customize_partial_blogname',
		) );
		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector'        => '.site-description',
			'render_callback' => 'akks_customize_partial_blogdescription',
		) );
	}
	
	// Load customize control.
	require trailingslashit( get_template_directory() ) . '/inc/customizer/control.php';	


	// Load customize sanitize.
	require trailingslashit( get_template_directory() ) . '/inc/customizer/sanitize.php';

	// Load customize callback.
	require trailingslashit( get_template_directory() ) . '/inc/customizer/callback.php';

	// Load customize theme options.
	require trailingslashit( get_template_directory() ) . '/inc/customizer/theme-options.php';	

	// Load customize home page options.
	require trailingslashit( get_template_directory() ) . '/inc/customizer/home-options.php';	

}
add_action( 'customize_register', 'akks_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function akks_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function akks_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function akks_customize_preview_js() {
	wp_enqueue_script( 'akks-customizer', get_template_directory_uri() . '/assets/js/customizer.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'akks_customize_preview_js' );

/**
 * Script for customizer 
 */
function akks_customize_backend_scripts() {

	wp_enqueue_style( 'akks-customizer-css', get_template_directory_uri() . '/inc/customizer/css/customizer.css' );

	wp_enqueue_script( 'akks-customizer-js', get_template_directory_uri() . '/inc/customizer/js/customizer-js.js', array( ), '1.0.0', true );
}
add_action( 'customize_controls_enqueue_scripts', 'akks_customize_backend_scripts', 10 );
